@@ -2,42 +2,37 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Təqvim",
-    "Group" : "Qrup",
-    "Share Calendar" : "Təqvimi yayımla",
-    "group" : "qrup",
-    "Attendees" : "İştirakçılar",
-    "Repeating" : "Təkrarlanır",
-    "None" : "Heç bir",
-    "never" : "heç vaxt",
-    "hours" : "saatlar",
-    "days" : "günlər",
-    "week" : "həftə",
-    "Title of the Event" : "Hadisənin başlığı",
-    "Delete" : "Sil",
-    "Cancel" : "Dayandır",
-    "Create" : "Yarat",
-    "Update" : "Yenilənmə",
-    "Close" : "Bağla",
-    "Location" : "Yerləşdiyiniz ünvan",
-    "Description" : "Açıqlanma",
-    "Export" : "Çıxarış",
+    "Cheers!" : "Şərəfə!",
+    "Today" : "Bu gün",
     "Day" : "Gün",
     "Week" : "Həftə",
     "Month" : "Ay",
-    "Today" : "Bu gün",
-    "More" : "Daha da",
-    "Edit" : "Dəyişiklik et",
     "Download" : "Yüklə",
+    "Delete" : "Sil",
+    "Share link" : "Linki yayımla",
     "can edit" : "dəyişmək olar",
-    "New Calendar" : "Yeni təqvim",
-    "Name" : "Ad",
-    "Edit event" : "Hadisəni dəyişdir",
-    "Time" : "Vaxt",
-    "Repeat" : "Təkrar",
-    "Add" : "Əlavə etmək",
+    "New calendar" : "Yeni təqvim",
+    "Cancel" : "Dayandır",
+    "Automatic" : "Avtomatik",
+    "Email" : "Email",
     "from" : "ondan",
     "to" : "doğru",
-    "New calendar" : "Yeni təqvim",
-    "Primary CalDAV address" : "Əsas CalDAV ünvanı"
+    "never" : "heç vaxt",
+    "Repeat" : "Təkrar",
+    "Monday" : "Bazar ertəsi",
+    "More" : "Daha da",
+    "Save" : "Saxla",
+    "Update" : "Yenilənmə",
+    "Personal" : "Şəxsi",
+    "Details" : "Detallar",
+    "Attendees" : "İştirakçılar",
+    "Activity" : "Fəallıq",
+    "Close" : "Bağla",
+    "Daily" : "Günlük",
+    "Weekly" : "Həftəlik",
+    "Location" : "Yerləşdiyiniz ünvan",
+    "Description" : "Açıqlanma",
+    "Mail" : "Məktub",
+    "Play" : "Oxu"
 },
 "nplurals=2; plural=(n != 1);");
