@@ -2,46 +2,38 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "দিনপঞ্জী",
-    "Group" : "গোষ্ঠীসমূহ",
-    "Unknown" : "অজানা",
-    "Share Calendar" : "দিনপঞ্জী ভাগাভাগি করুন",
-    "Shared" : "ভাগাভাগিকৃত",
-    "group" : "দল",
-    "Attendees" : "অংশগ্রহণকারীবৃন্দ",
-    "Repeating" : "পূনঃসঘটিত হবে",
-    "None" : "কোনটিই নয়",
-    "never" : "কখনোই নয়",
-    "Audio" : "অডিও",
-    "hours" : "ঘন্টাসমূহ",
-    "days" : "দিনগুলি",
-    "week" : "সপ্তাহ",
-    "Title of the Event" : "ইভেন্টের শিরোনাম",
-    "Delete" : "মুছে",
-    "Cancel" : "বাতিল",
-    "Create" : "তৈরী কর",
-    "Update" : "পরিবর্ধন",
-    "Close" : "বন্ধ",
-    "Location" : "অবস্থান",
-    "Description" : "বিবরণ",
-    "Export" : "রপ্তানি",
+    "Cheers!" : "শুভেচ্ছা!",
+    "Today" : "আজ",
     "Day" : "দিবস",
     "Week" : "সপ্তাহ",
     "Month" : "মাস",
-    "Today" : "আজ",
-    "More" : "বেশী",
-    "Edit" : "সম্পাদনা",
     "Download" : "ডাউনলোড",
+    "Delete" : "মুছে",
+    "Share link" : "লিংক ভাগাভাগি করেন",
     "can edit" : "সম্পাদনা করতে পারবেন",
-    "New Calendar" : "নতুন দিনপঞ্জী",
-    "Name" : "নাম",
-    "Edit event" : "ইভেন্ট সম্পাদনা করুন",
-    "Time" : "সময়",
-    "Type" : "ধরণ",
-    "Repeat" : "পূনঃসংঘটন",
-    "Add" : "যোগ কর",
+    "New calendar" : "নতুন দিনপঞ্জী",
+    "Cancel" : "বাতিল",
+    "Automatic" : "স্বয়ংক্রিয়",
+    "Email" : "ইমেইল",
+    "Unknown" : "অজানা",
     "from" : "হইতে",
     "to" : "প্রতি",
-    "New calendar" : "নতুন দিনপঞ্জী",
-    "Primary CalDAV address" : "প্রাথমিক CalDAV ঠিকানা"
+    "never" : "কখনোই নয়",
+    "Repeat" : "পূনঃসংঘটন",
+    "Monday" : "সোমবার",
+    "More" : "বেশী",
+    "Save" : "সংরক্ষণ",
+    "Update" : "পরিবর্ধন",
+    "Personal" : "ব্যক্তিগত",
+    "Details" : "বিসতারিত",
+    "Attendees" : "অংশগ্রহণকারীবৃন্দ",
+    "Activity" : "সক্রিয়তা",
+    "Close" : "বন্ধ",
+    "Daily" : "দৈনিক",
+    "Weekly" : "সাপ্তাহিক",
+    "Location" : "অবস্থান",
+    "Description" : "বিবরণ",
+    "Mail" : "মেইল",
+    "Play" : "বাজাও"
 },
 "nplurals=2; plural=(n != 1);");
