@@ -2,43 +2,38 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalendar",
-    "Group" : "Grupa",
-    "Share Calendar" : "Podijeli Kalendar",
-    "Shared" : "Podijeljen",
-    "group" : "grupa",
-    "Attendees" : "Sudionici",
-    "Repeating" : "Ponavljanje",
-    "None" : "Ništa",
-    "never" : "nikad",
-    "hours" : "sati",
-    "days" : "dana",
-    "week" : "sedmica",
-    "Title of the Event" : "Naslov Događaja",
-    "Delete" : "Obriši",
-    "Cancel" : "Odustani",
-    "Create" : "Kreiraj",
-    "Update" : "Ažuriraj",
-    "Close" : "Zatvori",
-    "Location" : "Lokacija",
-    "Description" : "Opis",
-    "Export" : "Izvezi",
+    "Cheers!" : "Cheers!",
+    "Today" : "Danas",
     "Day" : "Dan",
     "Week" : "Sedmica",
     "Month" : "Mjesec",
-    "Today" : "Danas",
-    "More" : "Više",
-    "Edit" : "Izmjeni",
-    "Link" : "Veza",
     "Download" : "Preuzmi",
+    "Delete" : "Obriši",
+    "Share link" : "Podijelite vezu",
     "can edit" : "mogu mijenjati",
-    "New Calendar" : "Novi Kalendar",
-    "Name" : "Ime",
-    "Edit event" : "Izmjeni događaj",
-    "Repeat" : "Ponovi",
-    "Add" : "Dodaj",
+    "New calendar" : "Novi kalendar",
+    "Cancel" : "Odustani",
+    "Email" : "E-pošta",
+    "Busy" : "Zauzet",
+    "Unknown" : "Nepoznato",
     "from" : "od",
     "to" : "do",
-    "New calendar" : "Novi kalendar",
-    "Primary CalDAV address" : "Primarna CalDAV adresa"
+    "never" : "nikad",
+    "Repeat" : "Ponovi",
+    "Monday" : "Ponedjeljak",
+    "More" : "Više",
+    "Save" : "Spremi",
+    "Update" : "Ažuriraj",
+    "Personal" : "Osobno",
+    "Attendees" : "Sudionici",
+    "Activity" : "Aktivnost",
+    "Close" : "Zatvori",
+    "Daily" : "Dnevno",
+    "Weekly" : "Sedmično",
+    "Location" : "Lokacija",
+    "Description" : "Opis",
+    "Status" : "Status",
+    "Mail" : "E-Pošta",
+    "Play" : "Play"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
