@@ -7,50 +7,43 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Kami ingin menginformasikan anda bahwa %s telah mempublikasikan kalender »%s«.",
     "Open »%s«" : "Buka »%s«",
     "Cheers!" : "Horee!",
-    "Recipient" : "Penerima",
-    "Error connecting to remote server" : "Kesalahan terjadi saat menyambung ke remote server",
-    "Group" : "Grup",
-    "Unknown" : "Tidak diketahui",
-    "Share Calendar" : "Bagikan Kalender",
-    "Shared" : "Dibagikan",
-    "group" : "grup",
-    "Attendees" : "Peserta",
-    "Repeating" : "Diulang",
-    "None" : "Tidak ada",
-    "never" : "tidak pernah",
-    "Audio" : "Audio",
-    "min" : "min",
-    "hours" : "jam",
-    "days" : "hari",
-    "week" : "minggu",
-    "Title of the Event" : "Judul Agenda",
-    "Delete" : "Hapus",
-    "Cancel" : "Batal",
-    "Create" : "Buat",
-    "Update" : "Perbarui",
-    "Close" : "Tutup",
-    "Location" : "Lokasi",
-    "Description" : "Deskrisi",
-    "Export" : "Ekspor",
+    "Today" : "Hari Ini",
     "Day" : "Hari",
     "Week" : "Minggu",
     "Month" : "Bulan",
-    "Today" : "Hari Ini",
-    "More" : "Lainnya",
-    "Edit" : "Sunting",
-    "Link" : "Tautan",
     "Download" : "Unduh",
+    "Delete" : "Hapus",
+    "Share link" : "Bagikan tautan",
+    "Share with users or groups" : "Bagi dengan pengguna atau grup",
     "can edit" : "dapat disunting",
-    "New Calendar" : "Kalendar Baru",
-    "Name" : "Nama",
-    "Edit event" : "Sunting agenda",
-    "Time" : "Waktu",
-    "Type" : "tipe",
-    "Repeat" : "Ulangi",
-    "Add" : "Tambah",
+    "New calendar" : "Kalender baru",
+    "Filename" : "Nama berkas",
+    "Cancel" : "Batal",
+    "Automatic" : "Otomatis",
+    "Email" : "Surel",
+    "Unknown" : "Tidak diketahui",
     "from" : "dari",
     "to" : "untuk",
-    "New calendar" : "Kalender baru",
-    "Primary CalDAV address" : "Alamat CalDAV Utama"
+    "never" : "tidak pernah",
+    "Repeat" : "Ulangi",
+    "Monday" : "Senin",
+    "Summary" : "Kesimpulan",
+    "More" : "Lainnya",
+    "Save" : "Simpan",
+    "Update" : "Perbarui",
+    "Personal" : "Personal",
+    "Details" : "Detil",
+    "Attendees" : "Peserta",
+    "Activity" : "Aktifitas",
+    "Close" : "Tutup",
+    "Anniversary" : "Ulang tahun",
+    "Daily" : "Setiap hari",
+    "Weekly" : "Setiap minggu",
+    "Location" : "Lokasi",
+    "Description" : "Deskrisi",
+    "Cancelled" : "Dibatalkan",
+    "Categories" : "Kategori",
+    "Mail" : "Email",
+    "Play" : "Putar"
 },
 "nplurals=1; plural=0;");
