@@ -2,38 +2,35 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "ប្រតិទិន",
-    "Share Calendar" : "ចែក​រំលែក​ប្រតិទិន",
-    "Shared" : "បាន​ចែក​រំលែក",
-    "group" : "ក្រុម",
-    "Attendees" : "អ្នក​ចូលរួម",
-    "Repeating" : "ការ​ធ្វើ​ឡើង​វិញ",
-    "None" : "គ្មាន",
-    "never" : "មិនដែរ",
-    "Title of the Event" : "ឈ្មោះ​ព្រឹត្តិការណ៍",
-    "Delete" : "លុប",
-    "Cancel" : "បោះបង់",
-    "Create" : "បង្កើត",
-    "Update" : "ធ្វើ​បច្ចុប្បន្នភាព",
-    "Close" : "បិទ",
-    "Location" : "ទីតាំង",
-    "Description" : "ការ​អធិប្បាយ",
-    "Export" : "នាំចេញ",
+    "Today" : "ថ្ងៃ​នេះ",
     "Day" : "ថ្ងៃ",
     "Week" : "សប្ដាហ៍",
     "Month" : "ខែ",
-    "Today" : "ថ្ងៃ​នេះ",
-    "More" : "ច្រើន​ទៀត",
-    "Edit" : "កែប្រែ",
     "Download" : "ទាញយក",
+    "Delete" : "លុប",
+    "Share link" : "Share link",
     "can edit" : "អាច​កែប្រែ",
-    "New Calendar" : "ប្រតិទិន​ថ្មី",
-    "Name" : "ឈ្មោះ",
-    "Edit event" : "កែ​ព្រឹត្តិការណ៍",
-    "Time" : "ម៉ោង",
-    "Repeat" : "ធ្វើម្ដងទៀត",
-    "Add" : "បន្ថែម",
+    "New calendar" : "ប្រតិទិន​ថ្មី",
+    "Cancel" : "បោះបង់",
+    "Email" : "អ៊ីមែល",
     "from" : "ពី",
     "to" : "ទៅ",
-    "New calendar" : "ប្រតិទិន​ថ្មី"
+    "never" : "មិនដែរ",
+    "Repeat" : "ធ្វើម្ដងទៀត",
+    "Monday" : "ថ្ងៃចន្ទ",
+    "More" : "ច្រើន​ទៀត",
+    "Save" : "រក្សាទុក",
+    "Update" : "ធ្វើ​បច្ចុប្បន្នភាព",
+    "Personal" : "ផ្ទាល់​ខ្លួន",
+    "Details" : "ព័ត៌មាន​លម្អិត",
+    "Attendees" : "អ្នក​ចូលរួម",
+    "Activity" : "សកម្មភាព",
+    "Close" : "បិទ",
+    "Daily" : "រាល់ថ្ងៃ",
+    "Weekly" : "រាល់​សប្ដាហ៍",
+    "Location" : "ទីតាំង",
+    "Description" : "ការ​អធិប្បាយ",
+    "Mail" : "សំបុត្រ",
+    "Play" : "លេង"
 },
 "nplurals=1; plural=0;");
