@@ -2,37 +2,34 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalendar",
-    "Share Calendar" : "Kongsi Kalendar",
-    "group" : "kumpulan",
-    "Attendees" : "Jemputan",
-    "Repeating" : "Pengulangan",
-    "never" : "jangan",
-    "Title of the Event" : "Tajuk agenda",
-    "Delete" : "Padam",
-    "Cancel" : "Batal",
-    "Create" : "Buat",
-    "Update" : "Kemaskini",
-    "Close" : "Tutup",
-    "Location" : "Lokasi",
-    "Description" : "Keterangan",
-    "Export" : "Eksport",
+    "Today" : "Hari ini",
     "Day" : "Hari",
     "Week" : "Minggu",
     "Month" : "Bulan",
-    "Today" : "Hari ini",
-    "More" : "Lanjutan",
-    "Edit" : "Sunting",
     "Download" : "Muat turun",
+    "Delete" : "Padam",
+    "Share link" : "Share link",
     "can edit" : "boleh mengubah",
-    "New Calendar" : "Kalendar baru",
-    "Name" : "Nama",
-    "Edit event" : "Ubah peristiwa",
-    "Type" : "Jenis",
-    "Repeat" : "Ulang",
-    "Add" : "Tambah",
+    "New calendar" : "Kalendar baru",
+    "Cancel" : "Batal",
+    "Email" : "Email",
     "from" : "dari",
     "to" : "kepada",
-    "New calendar" : "Kalendar baru",
-    "Primary CalDAV address" : "Alamat CalDAV utama"
+    "never" : "jangan",
+    "Repeat" : "Ulang",
+    "Monday" : "Isnin",
+    "More" : "Lanjutan",
+    "Save" : "Simpan",
+    "Update" : "Kemaskini",
+    "Personal" : "Peribadi",
+    "Attendees" : "Jemputan",
+    "Activity" : "Aktiviti",
+    "Close" : "Tutup",
+    "Daily" : "Setiap hari",
+    "Weekly" : "Setiap minggu",
+    "Location" : "Lokasi",
+    "Description" : "Keterangan",
+    "Mail" : "Mel",
+    "Play" : "Main"
 },
 "nplurals=1; plural=0;");
