@@ -2,25 +2,25 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "کیلنڈر",
-    "Shared" : "اشتراک شدہ",
-    "group" : "مجموعہ",
-    "Title of the Event" : "تقریب کا عنوان",
-    "Delete" : "حذف کریں",
-    "Cancel" : "منسوخ کریں",
-    "Close" : "بند ",
-    "Location" : "مقام",
-    "Description" : "تصریح",
+    "Cheers!" : "واہ!",
+    "Today" : "آج",
     "Week" : "ہفتہ",
     "Month" : "ماہ",
-    "Today" : "آج",
-    "More" : "مزید",
-    "Edit" : "تدوین کریں",
     "Download" : "ڈاؤن لوڈ",
+    "Delete" : "حذف کریں",
+    "Share link" : "اشتراک لنک",
     "can edit" : "تبدیل کر سکے ھیں",
-    "New Calendar" : "جدید کیلنڈر",
-    "Name" : "اسم",
+    "New calendar" : "جدید کیلنڈر",
+    "Cancel" : "منسوخ کریں",
+    "Email" : "email",
+    "never" : "never",
     "Repeat" : "دہرایں",
-    "Add" : "شامل کریں",
-    "New calendar" : "جدید کیلنڈر"
+    "Monday" : "سوموار",
+    "More" : "مزید",
+    "Save" : "حفظ",
+    "Personal" : "شخصی",
+    "Close" : "بند ",
+    "Location" : "مقام",
+    "Description" : "تصریح"
 },
 "nplurals=2; plural=(n != 1);");
